==> rewrite-static-analysis-2.16.0-sources.jar: org/openrewrite/staticanalysis/TypecastParenPad.java <==
/*
 * Copyright 2024 the original author or authors.
 * <p>
 * Licensed under the Moderne Source Available License (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * https://docs.moderne.io/licensing/moderne-source-available-license
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.openrewrite.staticanalysis;

import org.jspecify.annotations.Nullable;
import org.openrewrite.*;
import org.openrewrite.java.JavaIsoVisitor;
import org.openrewrite.java.format.SpacesVisitor;
import org.openrewrite.java.style.Checkstyle;
import org.openrewrite.java.style.IntelliJ;
import org.openrewrite.java.style.SpacesStyle;
import org.openrewrite.java.style.TypecastParenPadStyle;
import org.openrewrite.java.tree.J;
import org.openrewrite.java.tree.JavaSourceFile;
import org.openrewrite.staticanalysis.groovy.GroovyFileChecker;

import java.util.Optional;

import static java.util.Objects.requireNonNull;

public class TypecastParenPad extends Recipe {
    @Override
    public String getDisplayName() {
        return "Typecast parenthesis padding";
    }

    @Override
    public String getDescription() {
        return "Fixes whitespace padding between a typecast type identifier and the enclosing left and right parentheses. " +
                "For example, when configured to remove spacing, `( int ) 0L;` becomes `(int) 0L;`.";
    }

    @Override
    public TreeVisitor<?, ExecutionContext> getVisitor() {
        return Preconditions.check(
                Preconditions.not(new GroovyFileChecker<>()),
                new JavaIsoVisitor<ExecutionContext>() {
                    SpacesStyle spacesStyle;
                    TypecastParenPadStyle typecastParenPadStyle;

                    @Override
                    public J visit(@Nullable Tree tree, ExecutionContext ctx) {
                        if (tree instanceof JavaSourceFile) {
                            SourceFile cu = (SourceFile) requireNonNull(tree);
                            spacesStyle = Optional.ofNullable(cu.getStyle(SpacesStyle.class)).orElse(IntelliJ.spaces());
                            typecastParenPadStyle = Optional.ofNullable(cu.getStyle(TypecastParenPadStyle.class)).orElse(Checkstyle.typecastParenPadStyle());

                            spacesStyle = spacesStyle.withWithin(spacesStyle.getWithin().withTypeCastParentheses(typecastParenPadStyle.getSpace()));
                        }
                        return super.visit(tree, ctx);
                    }

                    @Override
                    public J.TypeCast visitTypeCast(J.TypeCast typeCast, ExecutionContext ctx) {
                        J.TypeCast tc = super.visitTypeCast(typeCast, ctx);
                        return (J.TypeCast) new SpacesVisitor<>(spacesStyle, null, null, tc)
                                .visitNonNull(tc, ctx, getCursor().getParentTreeCursor().fork());
                    }
                }
        );
    }

}

==> rewrite-static-analysis-2.21.0-sources.jar: org/openrewrite/staticanalysis/TypecastParenPad.java <==
/*
 * Copyright 2024 the original author or authors.
 * <p>
 * Licensed under the Moderne Source Available License (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * https://docs.moderne.io/licensing/moderne-source-available-license
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.openrewrite.staticanalysis;

import org.jspecify.annotations.Nullable;
import org.openrewrite.*;
import org.openrewrite.java.JavaIsoVisitor;
import org.openrewrite.java.format.SpacesVisitor;
import org.openrewrite.java.style.Checkstyle;
import org.openrewrite.java.style.IntelliJ;
import org.openrewrite.java.style.SpacesStyle;
import org.openrewrite.java.style.TypecastParenPadStyle;
import org.openrewrite.java.tree.J;
import org.openrewrite.java.tree.JavaSourceFile;
import org.openrewrite.staticanalysis.groovy.GroovyFileChecker;
import org.openrewrite.style.Style;

public class TypecastParenPad extends Recipe {
    @Override
    public String getDisplayName() {
        return "Typecast parenthesis padding";
    }

    @Override
    public String getDescription() {
        return "Fixes whitespace padding between a typecast type identifier and the enclosing left and right parentheses. " +
                "For example, when configured to remove spacing, `( int ) 0L;` becomes `(int) 0L;`.";
    }

    @Override
    public TreeVisitor<?, ExecutionContext> getVisitor() {
        //noinspection NotNullFieldNotInitialized
        return Preconditions.check(
                Preconditions.not(new GroovyFileChecker<>()),
                new JavaIsoVisitor<ExecutionContext>() {
                    SpacesStyle spacesStyle;
                    TypecastParenPadStyle typecastParenPadStyle;

                    @Override
                    public @Nullable J visit(@Nullable Tree tree, ExecutionContext ctx) {
                        if (tree instanceof JavaSourceFile) {
                            SourceFile cu = (SourceFile) tree;
                            spacesStyle = Style.from(SpacesStyle.class, cu, IntelliJ::spaces);
                            typecastParenPadStyle = Style.from(TypecastParenPadStyle.class, cu, Checkstyle::typecastParenPadStyle);

                            spacesStyle = spacesStyle.withWithin(spacesStyle.getWithin().withTypeCastParentheses(typecastParenPadStyle.getSpace()));
                        }
                        return super.visit(tree, ctx);
                    }

                    @Override
                    public J.TypeCast visitTypeCast(J.TypeCast typeCast, ExecutionContext ctx) {
                        J.TypeCast tc = super.visitTypeCast(typeCast, ctx);
                        return (J.TypeCast) new SpacesVisitor<>(spacesStyle, null, null, tc)
                                .visitNonNull(tc, ctx, getCursor().getParentTreeCursor().fork());
                    }
                }
        );
    }

}
